import { Component, EventEmitter, inject, Input, Output } from '@angular/core';
import { MatListModule } from '@angular/material/list';
import RedeemableAction from '../../shared/models/redeemable-action';
import { MatButtonModule } from '@angular/material/button';
import { MatFormFieldModule } from '@angular/material/form-field';
import { MatIconModule } from '@angular/material/icon';
import { MatDialog } from '@angular/material/dialog';
import { ActionItemEditComponent } from '../action-item-edit/action-item-edit.component';
import { HermesClientService } from '../../hermes-client.service';
import { MatSelectModule } from '@angular/material/select';

@Component({
  selector: 'action-list',
  standalone: true,
  imports: [
    MatButtonModule,
    MatFormFieldModule,
    MatIconModule,
    MatListModule,
    MatSelectModule,
  ],
  templateUrl: './action-list.component.html',
  styleUrl: './action-list.component.scss'
})
export class ActionListComponent {
  @Input() actions: RedeemableAction[] = []
  @Output() actionsChange = new EventEmitter<RedeemableAction>();

  readonly dialog = inject(MatDialog);
  readonly client = inject(HermesClientService);

  opened = false;

  create(): void {
    this.openDialog({ user_id: '', name: '', type: '', data: {} });
  }

  modify(action: RedeemableAction): void {
    this.openDialog(action);
  }

  private openDialog(action: RedeemableAction): void {
    if (this.opened)
      return;

    this.opened = true;

    const dialogRef = this.dialog.open(ActionItemEditComponent, {
      data: { action: { user_id: action.user_id, name: action.name, type: action.type, data: action.data }, actions: this.actions },
    });

    const isNewAction = action.name.length <= 0;
    dialogRef.afterClosed().subscribe((result: RedeemableAction | undefined) => {
      this.opened = false;
      if (!result)
        return;

      if (isNewAction) {
        this.actionsChange.emit(result);
      } else {
        action.type = result.type;
        action.data = result.data;
      }
    });
  }
}
