import { Component, inject, Input } from '@angular/core';
import { FormControl, ReactiveFormsModule } from '@angular/forms';
import { MatButtonModule } from '@angular/material/button';
import { MatCardModule } from '@angular/material/card';
import { MatFormFieldModule } from '@angular/material/form-field';
import { MatIconModule } from '@angular/material/icon';
import { Connection } from '../../shared/models/connection';
import { ConnectionItemComponent } from "../connection-item/connection-item.component";
import { MatInputModule } from '@angular/material/input';
import { MatDialog } from '@angular/material/dialog';
import { ConnectionItemEditComponent } from '../connection-item-edit/connection-item-edit.component';
import { MatSelectModule } from '@angular/material/select';
import { containsLettersInOrder } from '../../shared/utils/string-compare';

@Component({
  selector: 'connection-list',
  imports: [
    MatButtonModule,
    MatCardModule,
    MatFormFieldModule,
    MatIconModule,
    MatInputModule,
    MatSelectModule,
    ReactiveFormsModule,
    ConnectionItemComponent,
  ],
  templateUrl: './connection-list.component.html',
  styleUrl: './connection-list.component.scss'
})
export class ConnectionListComponent {
  private readonly _dialog = inject(MatDialog);

  private _connections: Connection[] = [];

  readonly searchControl = new FormControl<string>('');
  readonly typeControl = new FormControl<string>('');

  opened = false;


  get connections() {
    return this._connections.filter(c => containsLettersInOrder(c.name, this.searchControl.value) && (!this.typeControl.value || c.type == this.typeControl.value));
  }

  @Input({ required: true })
  set connections(value: Connection[]) {
    this._connections = value;
  }

  add() {
    if (this.opened)
      return;

    this.opened = true;

    const dialogRef = this._dialog.open(ConnectionItemEditComponent, {
      data: { name: this.searchControl.value },
    });

    dialogRef.afterClosed().subscribe((_: any) => this.opened = false);
  }
}
