import { Component, inject, Input, OnInit } from '@angular/core';
import { MatButtonModule } from '@angular/material/button';
import { MatCardModule } from '@angular/material/card';
import { MatFormFieldModule } from '@angular/material/form-field';
import { MatIconModule } from '@angular/material/icon';
import { Group } from '../../shared/models/group';
import { FormControl, FormGroup, ReactiveFormsModule, Validators } from '@angular/forms';
import { MAT_DIALOG_DATA, MatDialogRef } from '@angular/material/dialog';
import { MatInputModule } from '@angular/material/input';
import { HermesClientService } from '../../hermes-client.service';
import { integerValidator } from '../../shared/validators/integer';

@Component({
  selector: 'group-item-edit',
  imports: [
    MatButtonModule,
    MatCardModule,
    MatFormFieldModule,
    MatInputModule,
    MatIconModule,
    ReactiveFormsModule,
  ],
  templateUrl: './group-item-edit.component.html',
  styleUrl: './group-item-edit.component.scss'
})
export class GroupItemEditComponent implements OnInit {
  private readonly _client = inject(HermesClientService);
  private readonly _dialogRef = inject(MatDialogRef<GroupItemEditComponent>);
  private readonly _data = inject(MAT_DIALOG_DATA);

  group: Group = { id: '', user_id: '', name: '', priority: 0 };
  isSpecial: boolean = false;
  responseError: string | undefined;
  waitForResponse: boolean = false;

  nameForm = new FormControl('', [Validators.required]);
  priorityForm = new FormControl(0, [Validators.required, Validators.min(-2147483648), Validators.max(2147483647), integerValidator]);
  formGroup = new FormGroup({
    name: this.nameForm,
    priority: this.priorityForm,
  });

  ngOnInit() {
    this.group = this._data.group;
    this.isSpecial = this._data.isSpecial;
    this.nameForm.setValue(this.group.name);
    if (this.isSpecial)
      this.nameForm.disable();
    this.priorityForm.setValue(this.group.priority);
  }

  add() {
    if (this.formGroup.invalid || this.waitForResponse)
      return;

    this.waitForResponse = true;
    this.responseError = undefined;
    this._client.first((d: any) => d.op == 4 && d.d.request.type == 'create_group' && d.d.data.name == this.nameForm.value)
      .subscribe({
        next: (d) => {
          if (d.d.error) {
            this.responseError = d.d.error;
          } else {
            this._dialogRef.close(d.d.data);
          }
        },
        error: () => this.responseError = 'Something went wrong.',
        complete: () => this.waitForResponse = false,
      });
    this._client.createGroup(this.nameForm.value!, this.priorityForm.value!);
  }

  cancel() {
    this._dialogRef.close();
  }
}
