import { Component, inject, Input } from '@angular/core';
import { FormControl, ReactiveFormsModule } from '@angular/forms';
import { MatButtonModule } from '@angular/material/button';
import { MatCardModule } from '@angular/material/card';
import { MatFormFieldModule } from '@angular/material/form-field';
import { MatIconModule } from '@angular/material/icon';
import { MatInputModule } from '@angular/material/input';
import { MatDialog } from '@angular/material/dialog';
import { MatSelectModule } from '@angular/material/select';
import { containsLettersInOrder } from '../../shared/utils/string-compare';
import { KeyItemComponent } from '../key-item/key-item.component';
import { KeyItemEditComponent } from '../key-item-edit/key-item-edit.component';
import ApiKey from '../../shared/models/api-key';

@Component({
  selector: 'key-list',
  imports: [
    MatButtonModule,
    MatCardModule,
    MatFormFieldModule,
    MatIconModule,
    MatInputModule,
    MatSelectModule,
    ReactiveFormsModule,
    KeyItemComponent,
  ],
  templateUrl: './key-list.component.html',
  styleUrl: './key-list.component.scss'
})
export class KeyListComponent {
  private readonly _dialog = inject(MatDialog);

  private _keys: ApiKey[] = [];

  readonly searchControl = new FormControl<string>('');

  opened = false;


  get keys() {
    return this._keys.filter(c => containsLettersInOrder(c.label, this.searchControl.value));
  }

  @Input({ required: true })
  set keys(value: ApiKey[]) {
    this._keys = value;
  }

  add() {
    if (this.opened)
      return;

    this.opened = true;

    const dialogRef = this._dialog.open(KeyItemEditComponent, {
      data: { name: this.searchControl.value },
    });

    dialogRef.afterClosed().subscribe((_: any) => this.opened = false);
  }
}
