import { Component, inject, OnDestroy } from '@angular/core';
import { AuthVisitorGuard } from '../../shared/auth/auth.visitor.guard';
import { MatToolbarModule } from '@angular/material/toolbar';
import { MatIconModule } from '@angular/material/icon';
import { MatButtonModule } from '@angular/material/button';
import { AuthModule } from '../../auth/auth.module';
import { ApiAuthenticationService } from '../../shared/services/api/api-authentication.service';
import { ImpersonationComponent } from '../../auth/impersonation/impersonation.component';
import { HermesClientService } from '../../hermes-client.service';
import EventService from '../../shared/services/EventService';
import { Subscription } from 'rxjs';
import { ThemeComponent } from "../../theme/theme.component";

@Component({
  selector: 'topbar',
  standalone: true,
  imports: [
    AuthModule,
    ImpersonationComponent,
    MatButtonModule,
    MatIconModule,
    MatToolbarModule,
    ThemeComponent,
],
  providers: [AuthVisitorGuard],
  templateUrl: './topbar.component.html',
  styleUrl: './topbar.component.scss'
})
export class Topbar implements OnDestroy {
  private readonly auth = inject(ApiAuthenticationService);
  private readonly client = inject(HermesClientService);
  private readonly events = inject(EventService);

  private subscriptions: (Subscription | null)[] = [];
  private _showImpersonation: boolean = false

  constructor() {
    this.subscriptions.push(this.events.listen('impersonation', () => this.showImpersonation = false));
  }

  ngOnDestroy(): void {
    for (let subscription of this.subscriptions) {
      if (subscription) {
        subscription.unsubscribe();
      }
    }
  }

  get isLoggedIn() {
    return this.auth.isAuthenticated();
  }

  get isAdminLoggedIn() {
    return this.auth.isAuthenticated() && this.auth.isAdmin();
  }

  get username() {
    return this.auth.getUsername();
  }

  get impersonatedId() {
    return this.auth.getImpersonatedId();
  }

  get impersonatedName() {
    return this.auth.getImpersonatedName();
  }

  get showImpersonation() {
    return this._showImpersonation;
  }

  set showImpersonation(value: any) {
    if (this.auth.isAdmin()) {
      this._showImpersonation = !!value;
    }
  }

  toggleSidebar() {
    this.events.emit('toggle_sidebar', undefined);
  }
}
