import { inject, Injectable } from '@angular/core';
import Redemption from '../models/redemption';
import { HermesClientService } from '../../hermes-client.service';
import { map, Observable, of } from 'rxjs';
import EventService from './EventService';

@Injectable({
  providedIn: 'root'
})
export default class RedemptionService {
  private readonly client = inject(HermesClientService);
  private readonly events = inject(EventService);
  private data: Redemption[] = []
  private loaded = false;
  create$: Observable<any> | undefined;
  update$: Observable<any> | undefined;
  delete$: Observable<any> | undefined;

  constructor() {
    this.create$ = this.client.filterByRequestType('create_redemption');
    this.update$ = this.client.filterByRequestType('update_redemption');
    this.delete$ = this.client.filterByRequestType('delete_redemption');

    this.create$?.subscribe(d => this.data.push(d.data));
    this.update$?.subscribe(d => {
      const redemption = this.data.find(r => r.id == d.data.id);
      if (redemption) {
        redemption.action_name = d.data.action_name;
        redemption.redemption_id = d.data.redemption_id;
        redemption.order = d.data.order;
        redemption.state = d.data.state;
      }
    });
    this.delete$?.subscribe(d => this.data = this.data.filter(r => r.id != d.request.data.id));

    this.events.listen('tts_logoff', () => {
      this.data = [];
      this.loaded = false;
    });
  }


  fetch() {
    if (this.loaded) {
      return of(this.data);
    }

    const $ = this.client.first(d => d.op == 4 && d.d.request.type == 'get_redemptions')!.pipe(map(d => d.d.data));
    $.subscribe(d => {
      this.data = d;
      this.loaded = true;
    });
    this.client.fetchRedemptions();
    return $;
  }
}
