import { HttpClient } from '@angular/common/http';
import { inject, Injectable } from '@angular/core';
import { of, catchError, EMPTY } from 'rxjs';
import { environment } from '../../../environments/environment';
import EventService from './EventService';
import { User } from '../models/user';

@Injectable({
  providedIn: 'root'
})
export class UserService {
  private readonly http = inject(HttpClient);
  private readonly events = inject(EventService);
  private users: User[] = [];
  private loaded = false;


  constructor() {
    this.events.listen('logoff', () => {
      this.users = [];
      this.loaded = false;
    });
  }

  fetch() {
    if (this.loaded)
      return of(this.users);

    const $ = this.http.get<User[]>(environment.API_HOST + '/admin/users', {
      headers: {
        'Authorization': 'Bearer ' + localStorage.getItem('jwt'),
      }
    });
    $.pipe(catchError(() => EMPTY))
      .subscribe({
        next: d => this.users = d,
        error: d => console.log('user service error:', d.error),
        complete: () => this.loaded = true,
      });
    return $;
  }
}
