import { Component, inject, Input } from '@angular/core';
import { GroupChatter } from '../../shared/models/group-chatter';
import { MatIconModule } from '@angular/material/icon';
import { MatInputModule } from '@angular/material/input';
import { MatButtonModule } from '@angular/material/button';
import { HermesClientService } from '../../hermes-client.service';
import EventService from '../../shared/services/EventService';

@Component({
  selector: 'twitch-user-item',
  imports: [
    MatButtonModule,
    MatIconModule,
    MatInputModule
  ],
  templateUrl: './twitch-user-item.component.html',
  styleUrl: './twitch-user-item.component.scss'
})
export class TwitchUserItemComponent {
  @Input({ required: true }) user: GroupChatter = { chatter_id: -1, chatter_label: '', user_id: '', group_id: '' };

  private readonly _client = inject(HermesClientService);
  private readonly _events = inject(EventService);

  waitForResponse = false;
  responseError: string | undefined;

  delete() {
    if (this.waitForResponse)
      return;

    this.waitForResponse = true;
    this.responseError = undefined;

    this._client.first(d => d.op == 4 && d.d.request.type == 'delete_group_chatter' && d.d.request.data.group == this.user.group_id && d.d.request.data.chatter == this.user.chatter_id)
      .subscribe({
        next: (d) => {
          if (d.d.error) {
            this.responseError = d.d.error;
          } else {
            this._events.emit('delete_group_chatter', this.user);
          }
        },
        error: () => this.responseError = 'Something went wrong.',
        complete: () => this.waitForResponse = false,
      });
    this._client.deleteGroupChatter(this.user.group_id, this.user.chatter_id.toString());
  }
}
